# Deriv

Deriv is a highly efficient autodiff library with a NumPy-like API.

This is an early alpha release. APIs will change.

## Features

- Manual gradient engine
- Cython-accelerated matrix ops
- NumPy-style syntax

More detailed documentation is coming soon :)
I have my assignments pending so have to go now :(